# Foo

## Living Standard, 1 January 1970

This version:
  http://example.com/foo
Editor:
  Example Editor

COPYRIGHT GOES HERE

## Abstract

Test of markdown inline link constructs

## 1. Fragment

[link]() this is fine

link this is normal

link cool too

link nice

link nice nice

link leave as-is

link also leave as-is

link fancy

link is OK, albeit spacy

link is OK

[link] (/uri) is not OK, you monster